@@ -5,7 +5,7 @@
    $ Author: Mirko Boehm $
    $ Copyright: (C) 2005-2013 Mirko Boehm $
    $ Contact: mirko@kde.org
-         http://www.kde.org
+         https://www.kde.org
          http://creative-destruction.me $
 
    This library is free software; you can redistribute it and/or
@@ -800,7 +800,8 @@ void JobTests::ResourceRestrictionPolicyBasicsTest()
     AppendCharacterJob g('g', &sequence);
     Collection collection;
     collection << a << b << c << d << e << f << g;
-    Q_FOREACH(AppendCharacterJob* job, QList<AppendCharacterJob*>() << &a << &b << &c << &d << &e << &f << &g) {
+    const QList<AppendCharacterJob*> lstJob = { &a, &b, &c, &d, &e, &f, &g };
+    for (AppendCharacterJob* job : lstJob) {
         QMutexLocker l(job->mutex());
         job->assignQueuePolicy(&restriction);
     }
